# CHANGELOG

<!-- version list -->

## v1.0.3 (2025-12-16)


## v1.0.2 (2025-12-16)

### Bug Fixes

- Add auto changelog
  ([`f5e942b`](https://github.com/ameijin/quicketl/commit/f5e942bd1574be1edd8a3c6bad1b62e5a3112458))


## v1.0.1 (2025-12-16)

### Documentation

- Update readme
  ([`aef6b31`](https://github.com/ameijin/quicketl/commit/aef6b3186b3dcec09b1e807c04b4eab557030b8d))


## v1.0.0 (2025-12-16)

- Initial Release
